Skip to contents

There are two steps needed to fine tune the graph optimisation with multigrain:

  1. Create a control object with multigrain_control().

  2. Define its behaviour with control_ functions:

Any unset parameters will automatically be set before running the optimisation. There are predefined defaults, but they are calibrated based on the pvals dimensions.

Usage

multigrain_control()

Value

A multigrain control object.

Examples

multigrain_control()
#> <multigrain_control>