control_nsim_local() allows you to set the number of local simulations.
control_nsim_global() allows you to set the number of global simulations.
Arguments
- ctrl
A multigrain_control object.
- nsim_local
The number of simulations to use when evaluating the trial success function in local optimisation.
If set and lower than the number of rows in the
pvalsmatrix,graph_optimise()will use a random sample ofnsim_localrows frompvalsfor local optimisation.If unset or greater than or equal to the number of rows in the
pvalsmatrix, all rows frompvalswill be used.
- nsim_global
The number of simulations to use when evaluating the trial success function in global optimisation. If unset, the minimum between 50000 and the number of sets of p-values will be used.
Value
A modified multigrain_control.
Examples
multigrain_control() |>
control_nsim_local(10000)
#> <multigrain_control>
#> local simulations: 10000
multigrain_control() |>
control_nsim_global(10000)
#> <multigrain_control>
#> global simulations: 10000