multigrain_verbosity() returns the option named multigrain_verbosity,
which controls multigrain's verbosity. There are 3 possible levels
("detail" > "info" > "silent"):
"info" (default): will only show milestones / informational messages highlighting the progress of the optimisation at coarse-grained level.
"detail": will show milestones and information about fine-grained optimisation events.
"silent": no information about the progress of the optimisation is printed to the console. Errors and warnings are still thrown normally.